@@ -1,5 +1,8 @@
-package WebService::Braintree::ApplePayGateway;
-$WebService::Braintree::ApplePayGateway::VERSION = '1.1';
+# vim: sw=4 ts=4 ft=perl
+
+package # hide from pause
+    WebService::Braintree::ApplePayGateway;
+
 use 5.010_001;
 use strictures 1;
 
@@ -8,6 +11,8 @@ with 'WebService::Braintree::Role::MakeRequest';
 
 has 'gateway' => (is => 'ro');
 
+use WebService::Braintree::_::ApplePay;
+
 sub registered_domains {
     my $self = shift;
     $self->_make_request("/processing/apple_pay/registered_domains", "get", undef);
