@@ -1,5 +1,7 @@
+# vim: sw=4 ts=4 ft=perl
+
 package WebService::Braintree::ClientToken;
-$WebService::Braintree::ClientToken::VERSION = '1.1';
+$WebService::Braintree::ClientToken::VERSION = '1.2';
 use 5.010_001;
 use strictures 1;
 
@@ -14,6 +16,10 @@ Mobile and Javascript.
 
 =cut
 
+use Moose;
+
+with 'WebService::Braintree::Role::Interface';
+
 use constant DEFAULT_VERSION => "2";
 
 =head1 CLASS METHODS
@@ -43,36 +49,10 @@ This will default to the DEFAULT_VERSION of 2.
 
 sub generate {
     my ($class, $params) = @_;
-    if (!exists $params->{version}) {
-        $params->{version} = DEFAULT_VERSION;
-    }
+    $params->{version} //= DEFAULT_VERSION;
 
     $class->gateway->client_token->generate($params);
 }
 
-sub gateway {
-    WebService::Braintree->configuration->gateway;
-}
-
-=head1 OBJECT METHODS
-
-None. Please see L</generate()> for more information.
-
-=cut
-
 1;
 __END__
-
-=head1 TODO
-
-=over 4
-
-=item Need to document the keys and values that are returned
-
-=item Need to document the required and optional input parameters
-
-=item Need to document the possible errors/exceptions
-
-=back
-
-=cut
