@@ -1,11 +1,16 @@
-package WebService::Braintree::DiscountGateway;
-$WebService::Braintree::DiscountGateway::VERSION = '1.1';
+# vim: sw=4 ts=4 ft=perl
+
+package # hide from pause
+    WebService::Braintree::DiscountGateway;
+
 use 5.010_001;
 use strictures 1;
 
 use Moose;
 with 'WebService::Braintree::Role::MakeRequest';
 
+use WebService::Braintree::_::Discount;
+
 use WebService::Braintree::Util qw(to_instance_array);
 
 has 'gateway' => (is => 'ro');
@@ -15,7 +20,7 @@ sub all {
 
     my $response = $self->gateway->http->get("/discounts");
     my $attrs = $response->{discounts} || [];
-    return to_instance_array($attrs, 'WebService::Braintree::Discount');
+    return to_instance_array($attrs, 'WebService::Braintree::_::Discount');
 }
 
 __PACKAGE__->meta->make_immutable;
