@@ -1,5 +1,8 @@
-package WebService::Braintree::DisputeGateway;
-$WebService::Braintree::DisputeGateway::VERSION = '1.1';
+# vim: sw=4 ts=4 ft=perl
+
+package # hide from pause
+    WebService::Braintree::DisputeGateway;
+
 use 5.010_001;
 use strictures 1;
 
@@ -11,6 +14,9 @@ use WebService::Braintree::Util qw(validate_id);
 
 has 'gateway' => (is => 'ro');
 
+use WebService::Braintree::_::Dispute;
+use WebService::Braintree::DisputeSearch;
+
 sub accept {
     my $self = shift;
     my ($id) = @_;
@@ -68,7 +74,7 @@ sub search {
     return $self->paginated_collection({
         method => 'post',
         url => "/disputes/advanced_search",
-        inflate => [qw/disputes dispute Dispute/],
+        inflate => [qw/disputes dispute _::Dispute/],
         search => $block->(WebService::Braintree::DisputeSearch->new),
     });
 }
