@@ -1,5 +1,8 @@
-package WebService::Braintree::PlanGateway;
-$WebService::Braintree::PlanGateway::VERSION = '1.1';
+# vim: sw=4 ts=4 ft=perl
+
+package # hide from pause
+    WebService::Braintree::PlanGateway;
+
 use 5.010_001;
 use strictures 1;
 
@@ -10,12 +13,14 @@ use WebService::Braintree::Util qw(to_instance_array);
 
 has 'gateway' => (is => 'ro');
 
+use WebService::Braintree::_::Plan;
+
 sub all {
     my $self = shift;
 
     my $response = $self->gateway->http->get("/plans");
     my $attrs = $response->{plans} || [];
-    return to_instance_array($attrs, 'WebService::Braintree::Plan');
+    return to_instance_array($attrs, 'WebService::Braintree::_::Plan');
 }
 
 __PACKAGE__->meta->make_immutable;
