@@ -1,5 +1,8 @@
-package WebService::Braintree::Role::MakeRequest;
-$WebService::Braintree::Role::MakeRequest::VERSION = '1.1';
+# vim: sw=4 ts=4 ft=perl
+
+package # hide from pause
+    WebService::Braintree::Role::MakeRequest;
+
 use 5.010_001;
 use strictures 1;
 
@@ -24,5 +27,19 @@ sub _make_request {
     }
 }
 
+sub _make_raw_request {
+    my($self, $path, $verb, @args) = @_;
+    my $response = $self->gateway->http->$verb($path, @args);
+
+    if (exists $response->{api_error_response}) {
+        return WebService::Braintree::ErrorResult->new(
+            $response->{api_error_response},
+        );
+    }
+    else {
+        return $response;
+    }
+}
+
 1;
 __END__
