@@ -1,5 +1,8 @@
-package WebService::Braintree::SettlementBatchSummaryGateway;
-$WebService::Braintree::SettlementBatchSummaryGateway::VERSION = '1.1';
+# vim: sw=4 ts=4 ft=perl
+
+package # hide from pause
+    WebService::Braintree::SettlementBatchSummaryGateway;
+
 use 5.010_001;
 use strictures 1;
 
@@ -9,6 +12,8 @@ use Carp qw(confess);
 
 has 'gateway' => (is => 'ro');
 
+use WebService::Braintree::_::SettlementBatchSummary;
+
 sub generate {
     my ($self, $settlement_date, $group_by_custom_field) = @_;
     my $params = {
