@@ -1,5 +1,7 @@
+# vim: sw=4 ts=4 ft=perl
+
 package WebService::Braintree::ValidationError;
-$WebService::Braintree::ValidationError::VERSION = '1.1';
+$WebService::Braintree::ValidationError::VERSION = '1.2';
 =head1 NAME
 
 WebService::Braintree::ValidationError
@@ -8,19 +10,17 @@ WebService::Braintree::ValidationError
 
 This class represents an error, usually from a failed validation.
 
+This class will only be created as part of a L<error response|WebService::Braintree::ErrorResult>.
+
 =cut
 
 use Moose;
 
-=head1 CLASS METHODS
-
-This class is B<NOT> an interface, so it does B<NOT> have any class methods.
-
-=head1 OBJECT METHODS
+=head1 METHODS
 
 =head2 attribute()
 
-This is the B<TODO>
+This is the attribute in the unsuccessful request which failed validation.
 
 =cut
 
@@ -28,7 +28,7 @@ has 'attribute' => (is => 'ro');
 
 =head2 code()
 
-This is the B<TODO>
+This is the validation error code returned from Braintree.
 
 =cut
 
@@ -36,7 +36,7 @@ has 'code' => (is => 'ro');
 
 =head2 message()
 
-This is the B<TODO>
+This is the explanatory message provided by Braintree for this error.
 
 =cut
 
@@ -46,13 +46,3 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 __END__
-
-=head1 TODO
-
-=over 4
-
-=item Need to document what the attributes actually mean.
-
-=back
-
-=cut
